@@ -40,7 +40,7 @@ def set_logging(log_dir: Optional[str] = None):
 
     Returns
     -------
-
+    None
     """
     if log_dir and log_dir != 'null':
         log_dir = os.path.abspath(log_dir)
@@ -68,6 +68,8 @@ def set_logging(log_dir: Optional[str] = None):
                 TqdmLoggingHandler()
             ],
         )
+    
+    return None
 
 
 def logging_args(args):
@@ -88,15 +90,8 @@ def logging_args(args):
     logger.info(f"Parameters: ({type(args)})")
     for arg_element, value in arg_elements.items():
         logger.info(f"  {arg_element}: {value}")
-
-
-def prettify_json(text, indent=2, collapse_level=4):
-    pattern = r"[\r\n]+ {%d,}" % (indent * collapse_level)
-    text = re.sub(pattern, ' ', text)
-    text = re.sub(r'([\[({])+ +', r'\g<1>', text)
-    text = re.sub(r'[\r\n]+ {%d}([])}])' % (indent * (collapse_level-1)), r'\g<1>', text)
-    text = re.sub(r'(\S) +([])}])', r'\g<1>\g<2>', text)
-    return text
+    
+    return None
 
 
 def remove_dir(directory: str):
@@ -134,8 +129,9 @@ def save_json(obj, path: str, collapse_level: Optional[int] = None):
     -------
     None
     """
-    file_dir = os.path.split(path)[0]
-    os.makedirs(file_dir, exist_ok=True)
+    file_dir = os.path.dirname(os.path.normpath(path))
+    if file_dir:
+        os.makedirs(file_dir, exist_ok=True)
 
     json_obj = json.dumps(obj, indent=2, ensure_ascii=False)
     if collapse_level:
